==> oscars_mgmnt_clms-0.0.5.dev20240208+28-py3-none-any.whl: oscars_mgmnt_clms/utils/es_support.py <==
"""
Created on 30 June 2019

@author: Tonneau Stephane
"""

from elasticsearch import Elasticsearch
from elasticsearch import helpers

# ELASTICSEARCH_LOGGER = logging.getLogger('elasticsearch')
# ELASTICSEARCH_LOGGER.setLevel(logging.CRITICAL)


class ElasticSupport(object):
    """class that provides basic support for elasticsearch querying."""

    @classmethod
    def get_search_all(cls, nbr=100):
        """ class method that returns a search query without any constraint,
        expect on the number of returned results.

        :param nbr: the number of results to return
        :type nbr: a string

        :returns: the query to provide to elastic search.
        :rtype: a string
        """
        es_list_coll = '{ "query": { "bool": { "must": [ { "match_all": { }}],"must_not": [ ],"should": [ ]}}, ' \
                       '"from": 0,"size": {}, "sort": [ ], "aggs": { } }'
        return es_list_coll.replace("{}", str(nbr))

    @classmethod
    def get_search_coll(cls, reference):
        """ class method that returns a search query to retrieve a document with
        a specific id.

        :param reference: the reference to find
        :type reference: a string

        :returns: the query to provide to elastic search.
        :rtype: a string
        """
        es_get_coll = '{ "query": { "bool": { "must": [ { "term": { "id": "{}"}}],"must_not": [ ],"should": [ ]}}, ' \
                      '"from": 0, "size": 1, "sort": [ ], "aggs": { } }'
        return es_get_coll.replace("{}", reference)

    @classmethod
    def get_search_wildcard(cls, field: str, expression: str) -> dict:
        """Get a search query to retrieve documents with a wildcard expression.

        :param field: field of the wildcard expression
        :param expression: wildcard expression
        """
        query = {
            "query": {
                "wildcard": {
                    field: {
                        "value": expression
                    }
                }
            },
            "_source": [field]
        }
        return query

    @classmethod
    def as_insert_action(cls, es_index, content, uid=None, es_type=None):
        """ get the structure information required to insert a provided
        line, within the elasticsearch server ( at specific index).

        :param es_index: the index to use for the insert
        :type es_index: str
        :param es_type: the type of document that shall be inserted
        :type es_type: str
        :param content: the document to insert
        :type content: str
        :param uid: a unique reference
        :type uid: str

        :returns: the action request
        :rtype: a structure
        """
        action = {
            "_index": es_index,
            "_source": content.replace("\r", "").replace("\n", "")
        }
        if es_type is not None:
            action["_type"] = es_type
        if (uid is not None) and (len(uid) < 512):
            action["_id"] = uid
        return action

    @classmethod
    def as_upsert_action(cls, es_index, doc, upsert, uid=None):
        """ get the structure information required to upsert the provided content

        :param es_index: the index to use for the upsert
        :type es_index: str
        :param doc: the (partial) document to use for update
        :type doc: dict
        :param upsert: the document to use for a new insert
        :type upsert: dict
        :param uid: unique reference of the document
        :type uid: str

        :returns: the action structure
        :rtype: dict
        """
        action = {
            "_op_type": "update",
            "_index": es_index,
            "doc": doc,
            "upsert": upsert
        }
        if (uid is not None) and (len(uid) < 512):
            action["_id"] = uid

        return action

    def __init__(self, config):
        """
        Initialisator of the class.
        """
        self.es_connector = Elasticsearch(
            config.es_servers,
            # sniff before doing anything
            sniff_on_start=False,
            # refresh nodes after a node fails to respond
            sniff_on_connection_fail=False,
            sniffer_timeout=60
        )

    def get(self, es_index, id):
        """ get a document from the index based on the id
        :param es_index: the index to retrieve the document from
        :type es_index: string
        :param id: the id of the document
        :type id: string
        :returns: the document
        :rtype: dictionary
        """
        return self.es_connector.get(es_index, id)

    def search(self, es_index, query):
        """ executes the search query on the ES server and return the results.

        :param es_index: the index to use for the search
        :type es_index: a string
        :param query: the document to insert
        :type query: a string

        :returns: the search results
        :rtype: a dictionary
        """
        return self.es_connector.search(es_index, query)

    def search_all(self, es_index: str, query):
        """Executes the search query on Elasticsearch and retrieves all results.

        :param es_index: Elasticsearch index
        :param query: search query
        """
        return helpers.scan(self.es_connector, index=es_index, query=query)

    def bulk_insert(self, actions):
        """ insert several documents in the ES server.

        :param actions: the list of actions to perform on the server
        :type actions: an array

        :returns: the status of the request
        :rtype: a string
        """
        return helpers.bulk(self.es_connector, actions)

    def single_insert(self, index, body, uid=None):
        """ insert a single document in the ES server.

        :param index: the index to use for the insert
        :type index: str
        :param body: the document to insert
        :type body: str
        :param uid: the uid of the document (optional)
        :type uid: str

        :returns: the status of the request
        :rtype: a string
        """
        return self.es_connector.index(index, body, id=uid)

    def single_upsert(self, index, doc, upsert, uid=None):
        """ upsert a single document in Elasticsearch

        :param index: the index to use for the upsert
        :type index: str
        :param doc: the (partial) document to use for update
        :type doc: dict
        :param upsert: the document to use for a new insert
        :type upsert: dict
        :param uid: unique reference of the document
        :type uid: str
        """
        body = {
            "doc": doc,
            "upsert": upsert
        }
        return self.es_connector.update(index, id=uid, body=body)

==> oscars_mgmnt_clms-0.0.7.dev20240314+34-py3-none-any.whl: oscars_mgmnt_clms/utils/es_support.py <==
"""
Created on 30 June 2019

@author: Tonneau Stephane
"""

from elasticsearch import Elasticsearch
from elasticsearch import helpers

# ELASTICSEARCH_LOGGER = logging.getLogger('elasticsearch')
# ELASTICSEARCH_LOGGER.setLevel(logging.CRITICAL)


class ElasticSupport(object):
    """class that provides basic support for elasticsearch querying."""

    @classmethod
    def get_search_all(cls, nbr=100):
        """ class method that returns a search query without any constraint,
        expect on the number of returned results.

        :param nbr: the number of results to return
        :type nbr: a string

        :returns: the query to provide to elastic search.
        :rtype: a string
        """
        es_list_coll = '{ "query": { "bool": { "must": [ { "match_all": { }}],"must_not": [ ],"should": [ ]}}, ' \
                       '"from": 0,"size": {}, "sort": [ ], "aggs": { } }'
        return es_list_coll.replace("{}", str(nbr))

    @classmethod
    def get_search_coll(cls, reference):
        """ class method that returns a search query to retrieve a document with
        a specific id.

        :param reference: the reference to find
        :type reference: a string

        :returns: the query to provide to elastic search.
        :rtype: a string
        """
        es_get_coll = '{ "query": { "bool": { "must": [ { "term": { "id": "{}"}}],"must_not": [ ],"should": [ ]}}, ' \
                      '"from": 0, "size": 1, "sort": [ ], "aggs": { } }'
        return es_get_coll.replace("{}", reference)

    @classmethod
    def get_search_wildcard(cls, field: str, expression: str) -> dict:
        """Get a search query to retrieve documents with a wildcard expression.

        :param field: field of the wildcard expression
        :param expression: wildcard expression
        """
        query = {
            "query": {
                "wildcard": {
                    field: {
                        "value": expression
                    }
                }
            },
            "_source": [field]
        }
        return query

    @classmethod
    def as_insert_action(cls, es_index, content, uid=None, es_type=None):
        """ get the structure information required to insert a provided
        line, within the elasticsearch server ( at specific index).

        :param es_index: the index to use for the insert
        :type es_index: str
        :param es_type: the type of document that shall be inserted
        :type es_type: str
        :param content: the document to insert
        :type content: str
        :param uid: a unique reference
        :type uid: str

        :returns: the action request
        :rtype: a structure
        """
        action = {
            "_index": es_index,
            "_source": content.replace("\r", "").replace("\n", "")
        }
        if es_type is not None:
            action["_type"] = es_type
        if (uid is not None) and (len(uid) < 512):
            action["_id"] = uid
        return action

    @classmethod
    def as_upsert_action(cls, es_index, doc, upsert, uid=None):
        """ get the structure information required to upsert the provided content

        :param es_index: the index to use for the upsert
        :type es_index: str
        :param doc: the (partial) document to use for update
        :type doc: dict
        :param upsert: the document to use for a new insert
        :type upsert: dict
        :param uid: unique reference of the document
        :type uid: str

        :returns: the action structure
        :rtype: dict
        """
        action = {
            "_op_type": "update",
            "_index": es_index,
            "doc": doc,
            "upsert": upsert
        }
        if (uid is not None) and (len(uid) < 512):
            action["_id"] = uid

        return action

    def __init__(self, config):
        """
        Initialisator of the class.
        """
        self.es_connector = Elasticsearch(
            config.es_servers,
            # sniff before doing anything
            sniff_on_start=False,
            # refresh nodes after a node fails to respond
            sniff_on_connection_fail=False,
            sniffer_timeout=60
        )

    def get(self, es_index, id):
        """ get a document from the index based on the id
        :param es_index: the index to retrieve the document from
        :type es_index: string
        :param id: the id of the document
        :type id: string
        :returns: the document
        :rtype: dictionary
        """
        return self.es_connector.get(index=es_index, id=id)

    def search(self, es_index, query):
        """ executes the search query on the ES server and return the results.

        :param es_index: the index to use for the search
        :type es_index: a string
        :param query: the document to insert
        :type query: a string

        :returns: the search results
        :rtype: a dictionary
        """
        return self.es_connector.search(index=es_index, body=query)

    def search_all(self, es_index: str, query):
        """Executes the search query on Elasticsearch and retrieves all results.

        :param es_index: Elasticsearch index
        :param query: search query
        """
        return helpers.scan(self.es_connector, index=es_index, query=query)

    def bulk_insert(self, actions):
        """ insert several documents in the ES server.

        :param actions: the list of actions to perform on the server
        :type actions: an array

        :returns: the status of the request
        :rtype: a string
        """
        return helpers.bulk(self.es_connector, actions)

    def single_insert(self, index, body, uid=None):
        """ insert a single document in the ES server.

        :param index: the index to use for the insert
        :type index: str
        :param body: the document to insert
        :type body: str
        :param uid: the uid of the document (optional)
        :type uid: str

        :returns: the status of the request
        :rtype: a string
        """
        return self.es_connector.index(index=index, document=body, id=uid)

    def single_upsert(self, index, doc, upsert, uid=None):
        """ upsert a single document in Elasticsearch

        :param index: the index to use for the upsert
        :type index: str
        :param doc: the (partial) document to use for update
        :type doc: dict
        :param upsert: the document to use for a new insert
        :type upsert: dict
        :param uid: unique reference of the document
        :type uid: str
        """
        body = {
            "doc": doc,
            "upsert": upsert
        }
        return self.es_connector.update(index=index, id=uid, body=body)
